@@ -1,6 +1,6 @@
 #-*- coding: UTF-8 -*-
 __name__ = "sci-clone"
-__version__ = "0.3.3.4"
+__version__ = "0.3.3.7"
 __url__ = "https://github.com/f10w3r/sci-clone"
 __banner__ = """
                                                                  
@@ -13,7 +13,7 @@ __banner__ = """
     A simple script for downloading articles from Sci-Hub.       
                                                                  
 """
-__description__ = "A simple script for downloading articles from Sci-Hub."
+__description__ = "A simple tool for cloning from Sci-Hub."
 __author__ = "f10w3r"
 __author_email__ = "lifuminster@gmail.com"
 __scihub__ = "sci-hub.tf"
\ No newline at end of file
